@@ -85,7 +85,6 @@ class StickProtocol():
             "signedPreKeyId": signedPreKey.keyId,
             "signature": signedPreKey.signature,
             "oneTimeId": user.oneTimeId,
-            "phone": user.phone
         }
         if preKey:
             PKB["preKey"] = preKey.public
@@ -198,6 +197,7 @@ class StickProtocol():
             chainId = stickId[36:]
             senderKey = EncryptingSenderKey.objects.filter(partyId=partyId, chainId=chainId, user=user).first()
         key = None
+        phone = None
         if senderKey:  # If the SenderKey exists, we will return it
             if memberId != user.id:
                 key = {'key': senderKey.key, 'identityKeyId': senderKey.identityKey.keyId}
@@ -209,7 +209,8 @@ class StickProtocol():
             if not PendingKey.objects.filter(user=user, stickId=stickId).exists():
                 owner = self.User.objects.get(id=memberId)
                 PendingKey.objects.create(user=user, owner=owner, stickId=stickId)
-        return {'authorized': authorized, 'senderKey': key}
+                phone = owner.phone
+        return {'authorized': authorized, 'senderKey': key, 'phone': phone}
 
     def get_standard_sender_keys(self, data, user, group):
         """
